@@ -98,7 +98,18 @@ class http_server:
         """
         self.async_update_list.append(f)
 
-    def route(self, method, path):
+    def default_cos_header(self):
+        """
+        返回默认跨站header
+        """
+        return {
+            "Access-Control-Allow-Origin": "*",
+            "Access-Control-Allow-Methods": "GET,POST",
+            "Access-Control-Allow-Credentials": "true",
+            "Access-Control-Allow-Headers": "*"
+        }
+
+    def route(self, method, path, option_headers=None):
         """装饰器,将异步函数装饰为访问route.
 
         @method: str : (get|post|put|delete|option)\n
@@ -112,11 +123,28 @@ class http_server:
             pass
 
         @server.route("get", "/{prefix}/test")
+        async def test_route(req)
+            pass
+
+        @server.route("get", "/{prefix}/test", server.default_cos_header())
+        async def test_route(req)
+            pass
+
+        @server.route("get", "/{prefix}/test", True)
         async def test_route(req)
             pass
         ```
         """
         def f(func):
+            oh = option_headers
             self.add_route(method, path, func)
+            if oh is not None:
+                if isinstance(oh, bool) and oh == True:
+                    oh = self.default_cos_header()
+
+                async def option_handler(request: web.Request):
+                    return web.Response(headers=oh)
+
+                self.app.router.add_options(path, option_handler)
             return func
         return f
